summaryrefslogtreecommitdiffstats
path: root/c/src/exec/score/cpu/sparc/cpu.h
diff options
context:
space:
mode:
Diffstat (limited to 'c/src/exec/score/cpu/sparc/cpu.h')
-rw-r--r--c/src/exec/score/cpu/sparc/cpu.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/c/src/exec/score/cpu/sparc/cpu.h b/c/src/exec/score/cpu/sparc/cpu.h
index b6bcb91738..5c0a9a2ca2 100644
--- a/c/src/exec/score/cpu/sparc/cpu.h
+++ b/c/src/exec/score/cpu/sparc/cpu.h
@@ -145,9 +145,9 @@ extern "C" {
/*
* Does this port provide a CPU dependent IDLE task implementation?
*
* If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
* must be provided and is the default IDLE thread body instead of
- * _Internal_threads_Idle_thread_body.
+ * _CPU_Thread_Idle_body.
*
* If FALSE, then use the generic IDLE thread body if the BSP does
* not provide one.
@@ -507,7 +507,7 @@ typedef struct {
void (*idle_task)( void );
boolean do_zero_of_workspace;
unsigned32 interrupt_stack_size;
- unsigned32 extra_system_initialization_stack;
+ unsigned32 extra_mpci_receive_server_stack;
} rtems_cpu_table;
/*
@@ -601,11 +601,11 @@ EXTERN unsigned8 _CPU_Trap_Table_area[ 8192 ]
/*
* Amount of extra stack (above minimum stack size) required by
- * system initialization thread. Remember that in a multiprocessor
- * system the system intialization thread becomes the MP server thread.
+ * MPCI receive server thread. Remember that in a multiprocessor
+ * system this thread must exist and be able to process all directives.
*/
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 1024
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 1024
/*
* This defines the number of entries in the ISR_Vector_table managed
@@ -898,13 +898,13 @@ void _CPU_ISR_install_vector(
#if (CPU_PROVIDES_IDLE_THREAD_BODY == TRUE)
/*
- * _CPU_Internal_threads_Idle_thread_body
+ * _CPU_Thread_Idle_body
*
* Some SPARC implementations have low power, sleep, or idle modes. This
* tries to take advantage of those models.
*/
-void _CPU_Internal_threads_Idle_thread_body( void );
+void _CPU_Thread_Idle_body( void );
#endif /* CPU_PROVIDES_IDLE_THREAD_BODY */
@@ -145,9 +145,9 @@ extern "C" {
* Does this port provide a CPU dependent IDLE task implementation?
*
- * If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
+ * If TRUE, then the routine _CPU_Thread_Idle_body
* must be provided and is the default IDLE thread body instead of